@@ -1,20 +1,27 @@
 import typer
 
+from .. import (
+    __version__,
+)
 from ..consoles import (
     console,
 )
-from .init import app as init_app
 from .new import app as new_app
 from .set import app as set_app
 from .utils import app as utils_app
 
 app = typer.Typer(add_completion=False)
-app.add_typer(init_app, name="init")
 app.add_typer(new_app, name="new")
 app.add_typer(utils_app, name="utils")
 app.add_typer(set_app, name="set")
 
 
+@app.command()
+def version():
+    """CLI's version"""
+    console.print(f"Minos CLI {__version__}")
+
+
 @app.callback()
 def callback():
     """Minos CLI."""
